@@ -91,19 +91,24 @@ def template(ctx, taskKey):
 from testinlabel.TLA import TLA     # warning: don't edit this line and don't change the script name!!!
 
 #import your packages
+#import os
 
 class Export(ExportAbstract):
 
-    def __init__(self, tla: TLA):       # warning: don't edit this line and don't change the script name!!!
+    def __init__(self, tla: TLA, savePath):       # warning: don't edit this line and don't change the script name!!!
         self.tla = tla                  # warning: don't edit this line and don't change the script name!!!
         self.tla.SetKey("{taskKey}")  # warning: don't edit this line and don't change the script name!!!
         self.tla.GetLabelData()         # warning: don't edit this line and don't change the script name!!!
+        self.savePath = savePath        # warning: don't edit this line and don't change the script name!!!
 
     def exec(self):
         # edit following code to
         for item in self.tla.taskList:
             print(item)
             exit()
+            
+            #it is suggest that you should save you export data with self.savePath, in web server, it is a must
+            # saveFile = os.path.join(self.savePath, fileDir, filename)
 """
     with open("export.py", "w", encoding="utf-8") as sf:
         sf.write(codeContent)
@@ -136,10 +141,10 @@ def export(ctx, file):
             scriptPath = os.path.abspath('.')
         sys.path.append(scriptPath)
         from export import Export
-        ex = Export(ctx.obj)
+        ex = Export(ctx.obj, savePath=scriptPath)
     except Exception as e:
         print(e)
-        raise Exception(f"can't import Export")
+        raise Exception(f"can't import Export; [exec] method is required, please check if you have Implemented the function")
 
     ex.exec()
     click.echo("done!")
